@@ -1,13 +1,14 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
-'''
+"""
 @File    :   dictHelper.py
 @Time    :   2020/08/14
 @Author  :   Yaronzz
 @Version :   2.0
 @Contact :   yaronhuang@foxmail.com
-@Desc    :   
-'''
+@Desc    :  
+"""
+
 
 def get(obj, array: list):
     for item in array:
@@ -20,6 +21,7 @@ def get(obj, array: list):
 
 class DictTool(dict):
     def __init__(self, obj: dict):
+        super().__init__()
         self.kp = {}
         for k in obj.keys():
             self.__setitem__(k, obj[k])
